==> kom%2B%2B-0.5.tar.gz: kom++-0.5/Makefile.py <==
# Makefile template for kom++
# $Id: Makefile.py,v 1.3 1996/05/08 08:56:32 ceder Exp $
# Copyright (C) 1996  Per Cederqvist and Inge Wallin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

# Process this file with python to generate Makefile.in.

from pmg import *

m = komxxmakefile()

m.add_subdir("genclasses",
	     [("source",[]),
	      ("depend",[]),
	      ("all",[])],
	     "always")
# FIXME: depend & all beror av source i kom++
m.add_subdir("libkom++",
	     [("source",[]),
	      ("depend",[("genclasses","source")]),
	      ("all",[])],
	     "always")
m.add_subdir("libconnection",
	     [("depend",[("genclasses","source"),
			 ("libkom++","source")]),
	      ("all",[])],
	     "always")
m.add_subdir("libisc",
	     [("depend",[]),
	      ("all",[])],
	     "always")
m.add_subdir("tcl-clients",
	     [("depend",[("genclasses","source"),
			 ("libkom++","source")]),
	      ("all",[("genclasses","all"),
		      ("libconnection","all"),
		      ("libkom++","all"),
		      ("libisc","all"),
		      ("libtcl","all")]),
	      ("install",[]),
	      ("installdirs",[])],
	     ["TCL_CLIENT"])
m.add_subdir("libtcl",
	     [("all",[])],
	     ["TCL_CLIENT"])
m.add_subdir("py-clients",
	     [("source",[]),
	      ("depend",[("genclasses","source"),
			 ("libkom++","source")]),
	      ("all",[("genclasses","all"),
		      ("libconnection","all"),
		      ("libkom++","all"),
		      ("libisc","all")])],
	     ["PYTHON_GLUE"])
m.add_subdir("www",
	     [("all",[]),
	      ("install",[]),
	      ("installdirs",[])],
	     ["WWW_KOM"])

m.distclean("config.status")
m.distclean("config.cache")
m.clean("config.log")
m.clean("conftest*")
m.pure("configure")

m.emit()

print """\
info dvi:
	echo "Sorry, no documentation exists at this point."

check:
	echo "Sorry, no test suite exists at this point."

installcheck:
	echo "Sorry, no test suite exists at this point."

TAGS:
	cd tcl-clients; $(MAKE) TAGS

DISTDIR=kom++-$(VERSION)

dist: $(srcdir)/configure
	@# cd $(srcdir); ./mkmi
	@# Start by making a clean directory hierarchy for the distribution.
	@# If this fails, let it fail early.
	$(RM) -r $(DISTDIR)
	mkdir $(DISTDIR)
	mkdir $(DISTDIR)/doc
	mkdir $(DISTDIR)/genclasses
	mkdir $(DISTDIR)/libcompat
	mkdir $(DISTDIR)/libconnection
	mkdir $(DISTDIR)/libisc
	mkdir $(DISTDIR)/libisc/build
	mkdir $(DISTDIR)/libisc/demo
	mkdir $(DISTDIR)/libisc/doc
	mkdir $(DISTDIR)/libisc/man
	mkdir $(DISTDIR)/libisc/src
	mkdir $(DISTDIR)/libkom++
	mkdir $(DISTDIR)/tcl-clients
	mkdir $(DISTDIR)/libtcl
	mkdir $(DISTDIR)/libtcl/compat
	mkdir $(DISTDIR)/libtcl/doc
	mkdir $(DISTDIR)/libtcl/generic
	mkdir $(DISTDIR)/libtcl/library
	mkdir $(DISTDIR)/libtcl/mac
	mkdir $(DISTDIR)/libtcl/tests
	mkdir $(DISTDIR)/libtcl/unix
	mkdir $(DISTDIR)/libtcl/unix/dltest
	mkdir $(DISTDIR)/libtcl/win
	mkdir $(DISTDIR)/py-clients
	mkdir $(DISTDIR)/www
	mkdir $(DISTDIR)/www/html
	mkdir $(DISTDIR)/www/testsuite
	mkdir $(DISTDIR)/www/testsuite/lm.0
	mkdir $(DISTDIR)/www/testsuite/config
	@# Find all candidates for distribution.
	find $(srcdir) -type f -print > dist1.o
	@# Filter away everything that "make distclean" should remove.
	@# Don't do "make distclean", since we don't know if the Makefile
	@# reside in $(srcdir) or not.  Hairy as the following statement
	@# might seem, getting rid of it is even hairier.
	@# This also removes some junk files not intended for distribution.
	@# error-hiders is not distributed because we are not sure if we
	@# are going to use those files or not.  other-clients is currently
	@# not distributed because not even we can get the files in that
	@# directory to compile at this time.  "/CVS/" are state
	@# directories used internally by CVS.
	sed \\
	    -e /`echo $(srcdir)|sed 's=\\([/+.]\\)=\\\\\\\\\\1=g'`'\\/kom\\+\\+-/d' \\
	    -e '/~$$/d' \\
	    -e '/\\.incl$$/d' \\
	    -e '/\\.o$$/d' \\
	    -e '/\\.orig$$/d' \\
	    -e '/\\.pyc$$/d' \\
	    -e '/\\.tar$$/d' \\
	    -e '/\\.gz/d' \\
	    -e '/\\/#.*#$$/d' \\
	    -e '/\\/\\.#/d' \\
	    -e '/\\/\\.komrc/d' \\
	    -e '/\\/CVS\\//d' \\
	    -e '/\\/Mailinglist$$/d' \\
	    -e '/\\/Makefile$$/d' \\
	    -e '/\\/Makefile.in2$$/d' \\
	    -e '/\\/TAGS$$/d' \\
	    -e '/\\/config\\./d' \\
	    -e '/\\/conftest/d' \\
	    -e '/\\/core$$/d' \\
	    -e '/\\/dependencies$$/d' \\
	    -e '/\\/error-hiders\\//d' \\
	    -e '/\\/genclasses\\/.*\\.cc$$/d' \\
	    -e '/\\/genclasses\\/.*\\.h$$/d' \\
	    -e '/\\/lib.*\\.a$$/d' \\
	    -e '/\\/libcompat\\/strerror.*/d' \\
	    -e '/\\/other-clients\\//d' \\
	    -e '/\\/stamp-/d' \\
	    -e '/\\/stmp-/d' \\
	    -e '/\\/tcl-clients\\/fixfd$$/d' \\
	    -e '/\\/tcl-clients\\/nilkom$$/d' \\
	    -e '/\\/tcl-clients\\/tkom$$/d' \\
	    -e '/\\/tcl-clients\\/komiwish$$/d' \\
	    -e '/\\/tcl-clients\\/start_nilkom\\.tcl$$/d' \\
	    -e '/\\/tclIndex$$/d' \\
	    -e '/\\/test\\.cc$$/d' \\
	    -e '/\\/www\\/sc$$/d' \\
		< dist1.o > dist2.o
	@# Transform the file to a shellscript.  Each line in the shellscript
	@# will look like this:
	@#   $(LN) $(srcdir)/path/name $(DISTDIR)/path/name
	@# except that $(srcdir) and $(DISTDIR) (but not $(LN)) will have been
	@# filled in by make.
	sed -e 's/\\(.*\\)/\\1 \\1/' \\
	    -e s/`echo $(srcdir)|sed 's=\\([/.]\\)=\\\\\\\\\\1=g'`// \\
	    -e 's/\\([^ ]*\\) \\([^ ]*\\)/\\$$LN \\2 $(DISTDIR)\\1/' \\
		< dist2.o > dist3.o
	@# Create symlink farm.  If that fails (possibly because $(srcdir)
	@# is on another partition) try to use "cp" instead of "ln".
	if LN=ln sh -e dist3.o ; then \\
		echo ln apparently succeeded; \\
	else if LN=cp sh -e dist3.o ; then \\
		echo cp apparently succeeded; \\
	else exit 1; fi; fi
	@# Create a tar file.
	tar cf $(DISTDIR).tar $(DISTDIR)
	@# Compress it, but keep the uncompressed tar file.
	@# If the disk space fills up here, just remove the compressed file.
	gzip -9v < $(DISTDIR).tar > $(DISTDIR).tar.gz ||$(RM) $(DISTDIR).tar.gz

tags:
	etags -t *.h */*.h *.cc */*.cc

check-h:
	for i in genclasses/*.h $(top_srcdir)/libkom++/*.h \\
		$(top_srcdir)/libconnection/*.h $(top_srcdir)/tcl-clients/*.h;\\
	do \\
		case $${i} in \\
			*/libconnection/TEMPLATE.h) ;;	\\
			*)					\\
			    echo \\#include \\"$${i}\\" > test.cc ;	\\
			    echo \\#include \\"$${i}\\" >> test.cc ;	\\
			    echo $${i} ;	\\
			    $(CXX) $(CPPXXFLAGS) $(ALL_CXXFLAGS) -c test.cc ;;\\
		esac;	\\
	done
	rm test.cc
	for i in genclasses/*.h $(top_srcdir)/libkom++/*.h \\
		$(top_srcdir)/libconnection/*.h $(top_srcdir)/tcl-clients/*.h;\\
	do \\
		case $${i} in \\
			*/libconnection/TEMPLATE.h) ;;	\\
			*)					\\
				echo \\#include \\"$${i}\\" >> test.cc ;;	\\
		esac	\\
	done
	for i in genclasses/*.h $(top_srcdir)/libkom++/*.h \\
		$(top_srcdir)/libconnection/*.h $(top_srcdir)/tcl-clients/*.h;\\
	do \\
		case $${i} in \\
			*/libconnection/TEMPLATE.h) ;;	\\
			*)					\\
				echo \\#include \\"$${i}\\" >> test.cc ;;	\\
		esac	\\
	done
	$(CXX) $(CPPXXFLAGS) $(ALL_CXXFLAGS) -c test.cc
	@echo Note: libisc headers not checked.
"""

==> kom%2B%2B-0.6.tar.gz: kom++-0.6/Makefile.py <==
# Makefile template for kom++
# $Id: Makefile.py,v 1.7 1996/07/19 15:17:50 ceder Exp $
# Copyright (C) 1996  Per Cederqvist and Inge Wallin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

# Process this file with python to generate Makefile.in.

from pmg import *

m = komxxmakefile()

m.add_subdir("genclasses",
	     [("source",[]),
	      ("depend",[]),
	      ("all",[])],
	     "always")
# FIXME: depend & all beror av source i kom++
m.add_subdir("libkom++",
	     [("source",[]),
	      ("depend",[("genclasses","source")]),
	      ("all",[])],
	     "always")
m.add_subdir("libconnection",
	     [("depend",[("genclasses","source"),
			 ("libkom++","source")]),
	      ("all",[])],
	     "always")
m.add_subdir("libisc",
	     [("depend",[]),
	      ("all",[])],
	     "always")
m.add_subdir("tcl-clients",
	     [("source",[]),
	      ("depend",[("genclasses","source"),
			 ("libkom++","source")]),
	      ("all",[("genclasses","all"),
		      ("libconnection","all"),
		      ("libkom++","all"),
		      ("libisc","all"),
		      ("libtcl","all")]),
	      ("install",[]),
	      ("installdirs",[])],
	     ["TCL_CLIENT"])
m.add_subdir("libtcl",
	     [("all",[])],
	     ["TCL_CLIENT"])
m.add_subdir("py-clients",
	     [("source",[]),
	      ("depend",[("genclasses","source"),
			 ("libkom++","source")]),
	      ("all",[("genclasses","all"),
		      ("libconnection","all"),
		      ("libkom++","all"),
		      ("libisc","all")])],
	     ["PYTHON_GLUE"])
m.add_subdir("python",
	     [("all",[("libkom++","all"),
		      ("libisc","all"),
		      ("py-clients","all"),
		      ("genclasses","all"),
		      ("libconnection","all")]),
	      ("install",[])],
	     ["PYTHON_GLUE"])
m.add_subdir("www",
	     [("all",[]),
	      ("install",[]),
	      ("installdirs",[])],
	     ["WWW_KOM"])

m.distclean("config.status")
m.distclean("config.cache")
m.clean("config.log")
m.clean("conftest*")
m.pure("configure")

m.emit()

print """\
info dvi:
	echo "Sorry, no documentation exists at this point."

check:
	echo "Sorry, no test suite exists at this point."

installcheck:
	echo "Sorry, no test suite exists at this point."

TAGS:
	cd tcl-clients; $(MAKE) TAGS

DISTDIR=kom++-$(VERSION)

dist: $(srcdir)/configure
	@# cd $(srcdir); ./mkmi
	@# Start by making a clean directory hierarchy for the distribution.
	@# If this fails, let it fail early.
	$(RM) -r $(DISTDIR)
	mkdir $(DISTDIR)
	mkdir $(DISTDIR)/doc
	mkdir $(DISTDIR)/genclasses
	mkdir $(DISTDIR)/libcompat
	mkdir $(DISTDIR)/libconnection
	mkdir $(DISTDIR)/libisc
	mkdir $(DISTDIR)/libisc/build
	mkdir $(DISTDIR)/libisc/demo
	mkdir $(DISTDIR)/libisc/doc
	mkdir $(DISTDIR)/libisc/man
	mkdir $(DISTDIR)/libisc/src
	mkdir $(DISTDIR)/libkom++
	mkdir $(DISTDIR)/tcl-clients
	mkdir $(DISTDIR)/libtcl
	mkdir $(DISTDIR)/libtcl/compat
	mkdir $(DISTDIR)/libtcl/doc
	mkdir $(DISTDIR)/libtcl/generic
	mkdir $(DISTDIR)/libtcl/library
	mkdir $(DISTDIR)/libtcl/mac
	mkdir $(DISTDIR)/libtcl/tests
	mkdir $(DISTDIR)/libtcl/unix
	mkdir $(DISTDIR)/libtcl/unix/dltest
	mkdir $(DISTDIR)/libtcl/win
	mkdir $(DISTDIR)/py-clients
	mkdir $(DISTDIR)/python
	mkdir $(DISTDIR)/python/Demo
	mkdir $(DISTDIR)/python/Demo/classes
	mkdir $(DISTDIR)/python/Demo/comparisons
	mkdir $(DISTDIR)/python/Demo/cwilib
	mkdir $(DISTDIR)/python/Demo/dns
	mkdir $(DISTDIR)/python/Demo/embed
	mkdir $(DISTDIR)/python/Demo/ibrowse
	mkdir $(DISTDIR)/python/Demo/md5test
	mkdir $(DISTDIR)/python/Demo/pdist
	mkdir $(DISTDIR)/python/Demo/rpc
	mkdir $(DISTDIR)/python/Demo/scripts
	mkdir $(DISTDIR)/python/Demo/sgi
	mkdir $(DISTDIR)/python/Demo/sgi/al
	mkdir $(DISTDIR)/python/Demo/sgi/audio
	mkdir $(DISTDIR)/python/Demo/sgi/audio_stdwin
	mkdir $(DISTDIR)/python/Demo/sgi/cd
	mkdir $(DISTDIR)/python/Demo/sgi/flp
	mkdir $(DISTDIR)/python/Demo/sgi/gl
	mkdir $(DISTDIR)/python/Demo/sgi/gl/glstdwin
	mkdir $(DISTDIR)/python/Demo/sgi/sv
	mkdir $(DISTDIR)/python/Demo/sgi/video
	mkdir $(DISTDIR)/python/Demo/sockets
	mkdir $(DISTDIR)/python/Demo/stdwin
	mkdir $(DISTDIR)/python/Demo/stdwin/ibrowse
	mkdir $(DISTDIR)/python/Demo/threads
	mkdir $(DISTDIR)/python/Demo/tkinter
	mkdir $(DISTDIR)/python/Demo/tkinter/guido
	mkdir $(DISTDIR)/python/Demo/tkinter/matt
	mkdir $(DISTDIR)/python/Demo/tkinter/www
	mkdir $(DISTDIR)/python/Demo/www
	mkdir $(DISTDIR)/python/Doc
	mkdir $(DISTDIR)/python/Grammar
	mkdir $(DISTDIR)/python/Include
	mkdir $(DISTDIR)/python/Lib
	mkdir $(DISTDIR)/python/Lib/irix5
	mkdir $(DISTDIR)/python/Lib/linux1
	mkdir $(DISTDIR)/python/Lib/stdwin
	mkdir $(DISTDIR)/python/Lib/sunos4
	mkdir $(DISTDIR)/python/Lib/sunos5
	mkdir $(DISTDIR)/python/Lib/test
	mkdir $(DISTDIR)/python/Lib/tkinter
	mkdir $(DISTDIR)/python/Lib/win
	mkdir $(DISTDIR)/python/Misc
	mkdir $(DISTDIR)/python/Modules
	mkdir $(DISTDIR)/python/Objects
	mkdir $(DISTDIR)/python/PC
	mkdir $(DISTDIR)/python/PC/utils
	mkdir $(DISTDIR)/python/PC/vc15_lib
	mkdir $(DISTDIR)/python/PC/vc15_w31
	mkdir $(DISTDIR)/python/PC/wat_dos
	mkdir $(DISTDIR)/python/PC/wat_os2
	mkdir $(DISTDIR)/python/Parser
	mkdir $(DISTDIR)/python/Python
	mkdir $(DISTDIR)/python/Tools
	mkdir $(DISTDIR)/python/Tools/bgen
	mkdir $(DISTDIR)/python/Tools/bgen/bgen
	mkdir $(DISTDIR)/python/Tools/freeze
	mkdir $(DISTDIR)/python/Tools/modulator
	mkdir $(DISTDIR)/python/Tools/modulator/Templates
	mkdir $(DISTDIR)/python/Tools/scripts
	mkdir $(DISTDIR)/www
	mkdir $(DISTDIR)/www/html
	mkdir $(DISTDIR)/www/testsuite
	mkdir $(DISTDIR)/www/testsuite/lm.0
	mkdir $(DISTDIR)/www/testsuite/lm.1
	mkdir $(DISTDIR)/www/testsuite/sc.0
	mkdir $(DISTDIR)/www/testsuite/sc.1
	mkdir $(DISTDIR)/www/testsuite/sc.2
	mkdir $(DISTDIR)/www/testsuite/py.0
	mkdir $(DISTDIR)/www/testsuite/config
	@# Find all candidates for distribution.
	find $(srcdir) -type f -print > dist1.o
	@# Filter away everything that "make distclean" should remove.
	@# Don't do "make distclean", since we don't know if the Makefile
	@# reside in $(srcdir) or not.  Hairy as the following statement
	@# might seem, getting rid of it is even hairier.
	@# This also removes some junk files not intended for distribution.
	@# error-hiders is not distributed because we are not sure if we
	@# are going to use those files or not.  other-clients is currently
	@# not distributed because not even we can get the files in that
	@# directory to compile at this time.  "/CVS/" are state
	@# directories used internally by CVS.
	sed \\
	    -e /`echo $(srcdir)|sed 's=\\([/+.]\\)=\\\\\\\\\\1=g'`'\\/kom\\+\\+-/d' \\
	    -e '/~$$/d' \\
	    -e '/\\.incl$$/d' \\
	    -e '/\\.log$$/d' \\
	    -e '/\\.o$$/d' \\
	    -e '/\\.orig$$/d' \\
	    -e '/\\.sum$$/d' \\
	    -e '/\\.pyc$$/d' \\
	    -e '/\\.tar$$/d' \\
	    -e '/\\.gz/d' \\
	    -e '/\\/#.*#$$/d' \\
	    -e '/\\/\\.#/d' \\
	    -e '/\\/\\.komrc/d' \\
	    -e '/\\/CVS\\//d' \\
	    -e '/\\/Mailinglist$$/d' \\
	    -e '/\\/Makefile$$/d' \\
	    -e '/\\/Makefile.in2$$/d' \\
	    -e '/\\/TAGS$$/d' \\
	    -e '/\\/config\\.log$$/d' \\
	    -e '/\\/config\\.cache$$/d' \\
	    -e '/\\/config\\.status$$/d' \\
	    -e '/\\/conftest/d' \\
	    -e '/\\/core$$/d' \\
	    -e '/\\/dependencies$$/d' \\
	    -e '/\\/error-hiders\\//d' \\
	    -e '/\\/genclasses\\/.*\\.cc$$/d' \\
	    -e '/\\/genclasses\\/.*\\.h$$/d' \\
	    -e '/\\/lib.*\\.a$$/d' \\
	    -e '/\\/libcompat\\/strerror.*/d' \\
	    -e '/\\/other-clients\\//d' \\
	    -e '/\\/pyton\\/config\\.h$$/d' \\
	    -e '/\\/pyton\\/Modules\\/config\\.h$$/d' \\
	    -e '/\\/stamp-/d' \\
	    -e '/\\/stmp-/d' \\
	    -e '/\\/tcl-clients\\/fixfd$$/d' \\
	    -e '/\\/tcl-clients\\/nilkom$$/d' \\
	    -e '/\\/tcl-clients\\/tkom$$/d' \\
	    -e '/\\/tcl-clients\\/komiwish$$/d' \\
	    -e '/\\/tcl-clients\\/start_nilkom\\.tcl$$/d' \\
	    -e '/\\/tclIndex$$/d' \\
	    -e '/\\/test\\.cc$$/d' \\
	    -e '/\\/www\\/sc$$/d' \\
		< dist1.o > dist2.o
	@# Transform the file to a shellscript.  Each line in the shellscript
	@# will look like this:
	@#   $(LN) $(srcdir)/path/name $(DISTDIR)/path/name
	@# except that $(srcdir) and $(DISTDIR) (but not $(LN)) will have been
	@# filled in by make.
	sed -e 's/\\(.*\\)/\\1 \\1/' \\
	    -e s/`echo $(srcdir)|sed 's=\\([/.]\\)=\\\\\\\\\\1=g'`// \\
	    -e 's/\\([^ ]*\\) \\([^ ]*\\)/\\$$LN \\2 $(DISTDIR)\\1/' \\
		< dist2.o > dist3.o
	@# Create symlink farm.  If that fails (possibly because $(srcdir)
	@# is on another partition) try to use "cp" instead of "ln".
	if LN=ln sh -e dist3.o ; then \\
		echo ln apparently succeeded; \\
	else if LN=cp sh -e dist3.o ; then \\
		echo cp apparently succeeded; \\
	else exit 1; fi; fi
	@# Create a tar file.
	tar cf $(DISTDIR).tar $(DISTDIR)
	@# Compress it, but keep the uncompressed tar file.
	@# If the disk space fills up here, just remove the compressed file.
	gzip -9v < $(DISTDIR).tar > $(DISTDIR).tar.gz ||$(RM) $(DISTDIR).tar.gz

tags:
	etags -t *.h */*.h *.cc */*.cc

check-h:
	for i in genclasses/*.h $(top_srcdir)/libkom++/*.h \\
		$(top_srcdir)/libconnection/*.h $(top_srcdir)/tcl-clients/*.h;\\
	do \\
		case $${i} in \\
			*/libconnection/TEMPLATE.h) ;;	\\
			*)					\\
			    echo \\#include \\"$${i}\\" > test.cc ;	\\
			    echo \\#include \\"$${i}\\" >> test.cc ;	\\
			    echo $${i} ;	\\
			    $(CXX) $(CPPXXFLAGS) $(ALL_CXXFLAGS) -c test.cc ;;\\
		esac;	\\
	done
	rm test.cc
	for i in genclasses/*.h $(top_srcdir)/libkom++/*.h \\
		$(top_srcdir)/libconnection/*.h $(top_srcdir)/tcl-clients/*.h;\\
	do \\
		case $${i} in \\
			*/libconnection/TEMPLATE.h) ;;	\\
			*)					\\
				echo \\#include \\"$${i}\\" >> test.cc ;;	\\
		esac	\\
	done
	for i in genclasses/*.h $(top_srcdir)/libkom++/*.h \\
		$(top_srcdir)/libconnection/*.h $(top_srcdir)/tcl-clients/*.h;\\
	do \\
		case $${i} in \\
			*/libconnection/TEMPLATE.h) ;;	\\
			*)					\\
				echo \\#include \\"$${i}\\" >> test.cc ;;	\\
		esac	\\
	done
	$(CXX) $(CPPXXFLAGS) $(ALL_CXXFLAGS) -c test.cc
	@echo Note: libisc headers not checked.
"""
